ytree\.arbor\.tree\_node\_selector\.add\_tree\_node\_selector
=============================================================

.. currentmodule:: ytree.arbor.tree_node_selector

.. autofunction:: add_tree_node_selector